@@ -169,7 +169,8 @@ class CopyTask(SqlTask):
         )
 
         self.delete_key = self.config.delete_key
-        self.incremental_key = self.config.incremental_key
+        self.src_incremental_key = self.config.incremental_key
+        self.dst_incremental_key = self.config.incremental_key
         self.max_merge_rows = self.config.max_merge_rows
         self.max_batch_rows = self.config.max_batch_rows
         self.is_full_load = self.run_arguments["full_load"] or self.delete_key is None
@@ -177,15 +178,30 @@ class CopyTask(SqlTask):
         result = self.target_db._validate_ddl(self.config.ddl)
         if result.is_ok:
             self.ddl = result.value
+
+            # Check if the incremental_key in the destination needs renaming
+            if self.dst_incremental_key is not None and len(self.ddl["columns"]) > 0:
+                columns_dict = {
+                    c["name"]: c["dst_name"] or c["name"] for c in self.ddl["columns"]
+                }
+                self.dst_incremental_key = columns_dict[self.src_incremental_key]
         else:
             return result
 
         return Ok()
 
     def compile(self):
+        result = self.get_columns()
+        if result.is_err:
+            return result
+
         return self.execute(False, self.run_arguments["debug"], self.is_full_load)
 
     def run(self):
+        result = self.get_columns()
+        if result.is_err:
+            return result
+
         if self.max_merge_rows is not None:
             result = self.execute(
                 True,
@@ -212,7 +228,7 @@ class CopyTask(SqlTask):
         if self.target_table_exists:
             load_table = self.tmp_table
             load_schema = self.tmp_schema
-            if is_full_load or self.incremental_key is None:
+            if is_full_load or self.src_incremental_key is None:
                 steps.append("Move Table")
             else:
                 steps.append("Merge Tables")
@@ -223,10 +239,6 @@ class CopyTask(SqlTask):
         self.set_run_steps(steps)
 
         with self.step("Prepare Load"):
-            result = self.get_columns()
-            if result.is_err:
-                return result
-
             result = self.get_read_query(execute, debug, is_full_load, limit)
             if result.is_err:
                 return result
@@ -245,6 +257,7 @@ class CopyTask(SqlTask):
                     return Exc(e)
 
         with self.step("Load Data"):
+            n_records = 0
             if execute:
                 data_iter = self.source_db._read_data_stream(get_data_query)
                 n_records = self.target_db.load_data(
@@ -295,8 +308,6 @@ class CopyTask(SqlTask):
         source_table_def = self.source_db._get_table(
             self.source_table,
             self.source_schema,
-            # columns=[c["name"] for c in self.ddl["columns"]],
-            # required_existing=True,
         )
         if source_table_def is None:
             return Err(
@@ -339,17 +350,19 @@ class CopyTask(SqlTask):
 
             else:
                 # In any other case, we use the source
-                self.ddl["columns"] = [
-                    {"name": c.name, "type": self.target_db._py2sqa(c.type.python_type)}
-                    for c in self.source_table_def.columns
-                ]
+                for c in self.source_table_def.columns:
+                    try:
+                        col_type = self.target_db._py2sqa(c.type.python_type)
+                    except:
+                        col_type = c.type.compile(self.target_db.engine.dialect)
+                    self.ddl["columns"].append({"name": c.name, "type": col_type})
         else:
             # Fill up column types from the source table
             for col in self.ddl["columns"]:
                 if col.get("name") not in self.source_table_def.columns:
                     return Err(
                         "database_error",
-                        "source_table_missing_column",
+                        "source_table_missing_columns",
                         db=self.source_db.name,
                         table=self.source_table,
                         schema=self.source_schema,
@@ -357,18 +370,28 @@ class CopyTask(SqlTask):
                     )
 
                 if col.get("type") is None:
-                    col["type"] = self.target_db._py2sqa(
-                        self.source_table_def.columns[col["name"]].type.python_type
-                    )
+                    try:
+                        col["type"] = self.source_table_def.columns[
+                            col["name"]
+                        ].type.compile(self.target_db.engine.dialect)
+                    except:
+                        col["type"] = self.target_db._py2sqa(
+                            self.source_table_def.columns[col["name"]].type.python_type
+                        )
+
+        for col in self.ddl["columns"]:
+            col["src_name"] = col["name"]
+            if col.get("dst_name") is not None:
+                col["name"] = col["dst_name"]
 
         return Ok()
 
     def get_read_query(self, execute, debug, is_full_load, limit=None):
         # Get the incremental value
         last_incremental_value_query = (
-            f"SELECT MAX({self.incremental_key}) AS value\n"
+            f"SELECT MAX({self.dst_incremental_key}) AS value\n"
             f"FROM {'' if self.schema is None else self.schema +'.'}{self.table}\n"
-            f"WHERE {self.incremental_key} IS NOT NULL"
+            f"WHERE {self.dst_incremental_key} IS NOT NULL"
         )
         if debug:
             self.write_compilation_output(
@@ -376,7 +399,12 @@ class CopyTask(SqlTask):
             )
 
         get_data_query = select(
-            columns=[column(c["name"]) for c in self.ddl["columns"]],
+            columns=[
+                column(c["src_name"]).label(c["name"])
+                if c["src_name"] != c["name"]
+                else column(c["src_name"])
+                for c in self.ddl["columns"]
+            ],
             from_obj=self.source_table_def,
         )
         last_incremental_value = None
@@ -393,18 +421,24 @@ class CopyTask(SqlTask):
         if last_incremental_value is not None:
             get_data_query = get_data_query.where(
                 or_(
-                    self.source_table_def.c[self.incremental_key].is_(None),
-                    self.source_table_def.c[self.incremental_key]
+                    self.source_table_def.c[self.src_incremental_key].is_(None),
+                    self.source_table_def.c[self.src_incremental_key]
                     >= last_incremental_value,
                 )
             )
-        if debug:
-            self.write_compilation_output(get_data_query, "get_data")
 
-        if self.incremental_key is not None:
-            get_data_query = get_data_query.order_by(self.incremental_key)
+        if self.src_incremental_key is not None:
+            get_data_query = get_data_query.order_by(self.src_incremental_key)
 
         if limit is not None:
             get_data_query = get_data_query.limit(limit)
 
+        if debug:
+            try:
+                q = get_data_query.compile(compile_kwargs={"literal_binds": True})
+            except:
+                # compilation can fail when using values like dates
+                q = str(get_data_query)
+            self.write_compilation_output(q, "get_data")
+
         return Ok(get_data_query)
